CREATE DATABASE IF NOT EXISTS masters;
use mysql;
INSERT INTO user (Host,User,Password,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Reload_priv,Shutdown_priv,Process_priv,File_priv,Grant_priv,References_priv,Index_priv,Alter_priv) VALUES('localhost','nobody','','Y','Y','Y','Y','Y','Y','Y','N','N','N','Y','N','N','N');
FLUSH PRIVILEGES;
use masters;

CREATE TABLE mst_type (
  kind VARCHAR(10) NOT NULL,
  t_name VARCHAR(20) NOT NULL,
  PRIMARY KEY(kind)
)
TYPE=InnoDB;
GRANT ALL ON masters.mst_type TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE notice (
  sendtime DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  emp_cd VARCHAR(50) NOT NULL,
  title VARCHAR(50) NULL,
  body TEXT NULL,
  confirm CHAR(1) NULL,
  schedule_cd INTEGER NULL,
  schedule_date_cd INTEGER NULL,
  PRIMARY KEY(sendtime, emp_cd),
  INDEX emp_cd_ind(emp_cd)
)
TYPE=InnoDB;
GRANT ALL ON masters.notice TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE pnotice (
  sendtime DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  emp_cd VARCHAR(50) NOT NULL,
  seentime DATETIME NULL,
  reply CHAR(1) NULL,
  remark TEXT NULL,
  print_flg CHAR(1) DEFAULT '1',
  PRIMARY KEY(sendtime, emp_cd),
  INDEX emp_cd_ind(emp_cd)
)
TYPE=InnoDB;
GRANT ALL ON masters.pnotice TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE facility_category (
  fac_cat_cd VARCHAR(10) NOT NULL,
  fac_cat_name VARCHAR(100) NULL,
  enable VARCHAR(1) NOT NULL DEFAULT 't',
  PRIMARY KEY(fac_cat_cd)
)
TYPE=InnoDB;
GRANT ALL ON masters.facility_category TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE division (
  division VARCHAR(10) NOT NULL,
  div_name VARCHAR(50) NOT NULL,
  PRIMARY KEY(division)
)
TYPE=InnoDB;
GRANT ALL ON masters.division TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE facilities (
  fac_cd VARCHAR(10) NOT NULL,
  fac_name VARCHAR(100) NOT NULL,
  enable VARCHAR(1) NULL DEFAULT 'f',
  fac_cat_cd VARCHAR(10) NOT NULL,
  PRIMARY KEY(fac_cd),
  INDEX facilities_fac_cat_cd_fk(fac_cat_cd),
  FOREIGN KEY(fac_cat_cd)
    REFERENCES facility_category(fac_cat_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.facilities TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE employee (
  emp_cd VARCHAR(50) NOT NULL,
  emp_password VARCHAR(50) NOT NULL,
  last_name_j VARCHAR(10) NOT NULL,
  first_name_j VARCHAR(10) NOT NULL,
  last_name_e VARCHAR(20) NOT NULL,
  first_name_e VARCHAR(20) NOT NULL,
  last_name_kana VARCHAR(20) NOT NULL,
  first_name_kana VARCHAR(20) NOT NULL,
  sex VARCHAR(1) NULL,
  kind VARCHAR(10) NULL,
  division VARCHAR(10) NULL,
  birthday DATE NULL,
  join_date DATE NULL,
  retire_date DATE NULL,
  extension_no VARCHAR(10) NULL,
  home_postal VARCHAR(7) NULL,
  home_addr1 VARCHAR(100) NULL,
  home_addr2 VARCHAR(100) NULL,
  home_addr3 VARCHAR(100) NULL,
  home_phone VARCHAR(20) NULL,
  handy_phone VARCHAR(20) NULL,
  email VARCHAR(50) NULL,
  contact VARCHAR(100) NULL,
  sort_no VARCHAR(100) NULL,
  unify VARCHAR(1) NULL DEFAULT 'f',
  PRIMARY KEY(emp_cd),
  INDEX employee_kind_fk(kind),
  INDEX employee_division_fk(division),
  FOREIGN KEY(kind)
    REFERENCES mst_type(kind)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(division)
    REFERENCES division(division)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.employee TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE schedule2 (
  schedule_cd INTEGER NOT NULL,
  emp_cd VARCHAR(50) NOT NULL,
  scdl_plan TEXT NOT NULL,
  scdl_place VARCHAR(128) NULL,
  scdl_remarks TEXT NULL,
  flg_del VARCHAR(1) NULL DEFAULT 'f',
  flg_pub VARCHAR(1) NULL DEFAULT 't',
  flg_out VARCHAR(1) NULL DEFAULT 'f',
  PRIMARY KEY(schedule_cd),
  INDEX schedule2_emp_cd_fk(emp_cd),
  FOREIGN KEY(emp_cd)
    REFERENCES employee(emp_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.schedule2 TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE schedule_date (
  schedule_cd INTEGER NOT NULL,
  schedule_date_cd INTEGER NOT NULL,
  scdl_date DATE NOT NULL,
  scdl_s_time TIME NULL,
  scdl_e_time TIME NULL,
  scdl_remarks TEXT NULL,
  PRIMARY KEY(schedule_cd, schedule_date_cd),
  INDEX schedule_date_schedule_cd_fk(schedule_cd),
  FOREIGN KEY(schedule_cd)
    REFERENCES schedule2(schedule_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.schedule_date TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE wiz_event_member (
  schedule_cd INTEGER NOT NULL,
  schedule_date_cd INTEGER NOT NULL,
  emp_cd VARCHAR(50) NOT NULL,
  enable VARCHAR(1) NOT NULL DEFAULT '1',
  INDEX wiz_event_member_emp_cd_fk(emp_cd),
  INDEX wiz_event_member_schedule_date_cd_fk(schedule_cd, schedule_date_cd),
  FOREIGN KEY(emp_cd)
    REFERENCES employee(emp_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(schedule_cd, schedule_date_cd)
    REFERENCES schedule_date(schedule_cd, schedule_date_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.wiz_event_member TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE reservation (
  fac_cd VARCHAR(10) NOT NULL,
  emp_cd VARCHAR(50) NOT NULL,
  schedule_cd INTEGER NOT NULL,
  schedule_date_cd INTEGER NOT NULL,
  ac_date DATETIME NULL DEFAULT 'now',
  PRIMARY KEY(fac_cd, emp_cd, schedule_cd, schedule_date_cd),
  INDEX reservation_fac_cd_fk(fac_cd),
  INDEX reservation_emp_cd_fk(emp_cd),
  INDEX reservation_schedule_date_cd_fc(schedule_cd, schedule_date_cd),
  FOREIGN KEY(fac_cd)
    REFERENCES facilities(fac_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(emp_cd)
    REFERENCES employee(emp_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(schedule_cd, schedule_date_cd)
    REFERENCES schedule_date(schedule_cd, schedule_date_cd)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;
GRANT ALL ON masters.reservation TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE tmp_reservation (
  owner_emp_cd VARCHAR(50) NOT NULL,
  fac_cd VARCHAR(10) NOT NULL,
  PRIMARY KEY(owner_emp_cd, fac_cd)
)
TYPE=InnoDB;
GRANT ALL ON masters.tmp_reservation TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE tmp_event_member (
  owner_emp_cd VARCHAR(50) NOT NULL,
  emp_cd VARCHAR(50) NOT NULL,
  enable VARCHAR(1) NULL,
  PRIMARY KEY(owner_emp_cd, emp_cd)
)
TYPE=InnoDB;
GRANT ALL ON masters.tmp_event_member TO nobody;
FLUSH PRIVILEGES;






















CREATE TABLE IF NOT EXISTS appconf (
  gwap CHARACTER VARYING(10) NOT NULL,
  name CHARACTER VARYING(40) NOT NULL,
  enable CHARACTER VARYING(1) DEFAULT 'f',
  link CHARACTER VARYING(255),
  gazou CHARACTER VARYING(50),
  cngok CHARACTER VARYING(1) DEFAULT 'f',
  sort_order INTEGER,
  name_e CHARACTER VARYING(100),
  menu_category_id INTEGER,
  CONSTRAINT appconf_pkey PRIMARY KEY(gwap)
) type=innodb;
GRANT ALL ON masters.appconf TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS category (
  cat_cd CHARACTER VARYING(10) NOT NULL,
  cat_name CHARACTER VARYING(100) NOT NULL,
  enable CHARACTER VARYING(1) DEFAULT 'f',
  CONSTRAINT category_pkey PRIMARY KEY(cat_cd)
) type=innodb;
GRANT ALL ON masters.category TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS company (
  c_name CHARACTER VARYING(200) NOT NULL,
  ck_name CHARACTER VARYING(200),
  c_date DATE,
  capital INTEGER,
  homepage TEXT,
  email CHARACTER VARYING(100),
  boss CHARACTER VARYING(50)
) type=innodb;
GRANT ALL ON masters.company TO nobody;
FLUSH PRIVILEGES;




CREATE TABLE IF NOT EXISTS holiday (
  hdate DATE NOT NULL,
  hname CHARACTER VARYING(100) NOT NULL,
  flgorgin CHARACTER VARYING(1) DEFAULT 'f',
  CONSTRAINT holiday_pkey PRIMARY KEY(hdate)
) type=innodb;
GRANT ALL ON masters.holiday TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS mst_touban (
  touban_cd CHARACTER VARYING(10) NOT NULL,
  touban_name CHARACTER VARYING(100) NOT NULL,
  memo CHARACTER VARYING(255),
  CONSTRAINT mst_touban_pkey PRIMARY KEY(touban_cd)
) type=innodb;
GRANT ALL ON masters.mst_touban TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS touban (
  touban_cd CHARACTER VARYING(10) NOT NULL,
  touban_date DATE NOT NULL,
  emp_cd TEXT NOT NULL,
  CONSTRAINT touban_pkey PRIMARY KEY(touban_cd,touban_date),
  CONSTRAINT touban_touban_cd FOREIGN KEY(touban_cd) REFERENCES mst_touban(touban_cd)
) type=innodb;
GRANT ALL ON masters.touban TO nobody;
FLUSH PRIVILEGES;




CREATE TABLE IF NOT EXISTS mst_wflow (
  petition_cd CHARACTER VARYING(10) NOT NULL,
  petition_name CHARACTER VARYING(200) NOT NULL,
  petition_type CHARACTER VARYING(10) NOT NULL,
  send_end_mail VARCHAR(1) DEFAULT 't' NOT NULL,
  send_sanction_mail VARCHAR(1) DEFAULT 't' NOT NULL,
  send_remand_mail VARCHAR(1) DEFAULT 't' NOT NULL,
  send_withdrawal_mail VARCHAR(1) DEFAULT 't' NOT NULL,
  CONSTRAINT mst_wflow_pkey PRIMARY KEY(petition_cd)
) type=innodb;
GRANT ALL ON masters.mst_wflow TO nobody;
FLUSH PRIVILEGES;



CREATE TABLE IF NOT EXISTS administrators (
  emp_cd CHARACTER VARYING(50) NOT NULL,
  CONSTRAINT administrators_pkey PRIMARY KEY(emp_cd),
  CONSTRAINT administrators_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.administrators TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS casus (
  petition_time DATETIME NOT NULL,
  casus TEXT,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT casus_pkey PRIMARY KEY(petition_time),
  CONSTRAINT casus_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.casus TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS chief (
  emp_cd CHARACTER VARYING(50) NOT NULL,
  title CHARACTER VARYING(255),
  CONSTRAINT chief_pkey PRIMARY KEY(emp_cd),
  CONSTRAINT chief_emp_cd_foreign FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.chief TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS chiefemp (
  chief CHARACTER VARYING(50) NOT NULL,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT chiefemp_pkey PRIMARY KEY(chief,emp_cd),
  CONSTRAINT chiefemp_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.chiefemp TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS gwlog (
  record_time DATETIME NOT NULL,
  emp_cd CHARACTER VARYING(50)  NOT NULL,
  gwap CHARACTER VARYING(10),
  access CHARACTER VARYING(15),
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT gwlog_pkey PRIMARY KEY(record_time,emp_cd),
  CONSTRAINT gwlog_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.gwlog TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS monsche (
  sche_date DATE NOT NULL,
  seq INTEGER NOT NULL,
  tantou CHARACTER VARYING(50),
  schedule TEXT,
  division CHARACTER VARYING(10),
  INDEX division_ind(division),
  CONSTRAINT monsche_division FOREIGN KEY(division) REFERENCES division(division)
) type=innodb;
GRANT ALL ON masters.monsche TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS nextodd (
  petition_time DATETIME NOT NULL,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT nextodd_pkey PRIMARY KEY(petition_time),
  CONSTRAINT nextodd_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.nextodd TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS oddmans (
  petition_time DATETIME NOT NULL,
  petition_cd CHARACTER VARYING(10),
  emp_cd CHARACTER VARYING(50) NOT NULL,
  seq INTEGER NOT NULL,
  INDEX petition_cd_ind(petition_cd),
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT oddmans_pkey PRIMARY KEY(petition_time,emp_cd),
  CONSTRAINT oddmans_petition_cd FOREIGN KEY(petition_cd) REFERENCES mst_wflow(petition_cd),
  CONSTRAINT oddmans_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.oddmans TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS subcategory (
  subcat_cd VARCHAR(10) NOT NULL,
  subcat_name VARCHAR(100) NOT NULL,
  enable CHARACTER VARYING(1),
  cat_cd VARCHAR(10) NOT NULL,
  CONSTRAINT subcategory_pkey PRIMARY KEY(subcat_cd)
) type=innodb;
GRANT ALL ON masters.subcategory TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS record (
  filename TEXT NOT NULL,
  cat_cd VARCHAR(10) NOT NULL,
  subcat_cd VARCHAR(10) NOT NULL,
  remark TEXT,
  emp_cd VARCHAR(50) NOT NULL,
  up_time DATETIME NOT NULL,
  filesize INTEGER,
  INDEX cat_cd_ind(cat_cd),
  INDEX subcat_cd_ind(subcat_cd),
  INDEX emp_cd_ind(emp_cd),
  CONSTRAINT record_pkey PRIMARY KEY(up_time),
  CONSTRAINT record_cat_cd FOREIGN KEY(cat_cd) REFERENCES category(cat_cd),
  CONSTRAINT record_subcat_cd FOREIGN KEY(subcat_cd) REFERENCES subcategory(subcat_cd),
  CONSTRAINT record_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.record TO nobody;
FLUSH PRIVILEGES;



CREATE TABLE IF NOT EXISTS transactions (
  emp_cd CHARACTER VARYING(50) NOT NULL,
  trans_id TEXT NOT NULL,
  CONSTRAINT transactions_pkey PRIMARY KEY(emp_cd),
  CONSTRAINT transactions_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.transactions TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS whiteboard (
  emp_cd CHARACTER VARYING(50) NOT NULL,
  place CHARACTER VARYING(1) DEFAULT '0',
  ins_time DATETIME,
  destination TEXT,
  back_time TIME,
  write_emp CHARACTER VARYING(50) ,
  INDEX write_emp_cd_ind(write_emp),
  CONSTRAINT whiteboard_pkey PRIMARY KEY(emp_cd),
  CONSTRAINT whiteboard_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd),
  CONSTRAINT whiteboard_write_emp FOREIGN KEY(write_emp) REFERENCES employee(emp_cd)
) type=innodb;
GRANT ALL ON masters.whiteboard TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS workflow (
  petition_time DATETIME NOT NULL,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  petition_cd CHARACTER VARYING(6) NOT NULL,
  oddtime TEXT,
  oddall CHARACTER VARYING(1) DEFAULT 'f',
  time_begin DATETIME,
  time_end DATETIME,
  purpose TEXT,
  detail TEXT,
  etc TEXT,
  ammount INTEGER,
  ngflg CHARACTER VARYING(1) DEFAULT 'f',
  endflg CHARACTER VARYING(1) DEFAULT 'f',
  remark TEXT,
  filename TEXT,
  delflg CHARACTER VARYING(1) DEFAULT 'f',
  INDEX emp_cd_ind(emp_cd),
  INDEX petition_cd_ind(petition_cd),
  CONSTRAINT workflow_pkey PRIMARY KEY(petition_time),
  CONSTRAINT workflow_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd),
  CONSTRAINT workflow_petition_cd FOREIGN KEY(petition_cd) REFERENCES mst_wflow(petition_cd)
) type=innodb;
GRANT ALL ON masters.workflow TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS telmemo2 (
  regist_time DATETIME NOT NULL,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  purpose INTEGER NOT NULL,
  memo TEXT NOT NULL,
  writer CHARACTER VARYING(50) NOT NULL,
  del CHARACTER VARYING(1),
  INDEX emp_cd_ind(emp_cd),
  INDEX writer_cd_ind(writer),
  CONSTRAINT telmemo2_emp_cd FOREIGN KEY(emp_cd) REFERENCES employee(emp_cd),
  CONSTRAINT telmemo2_writer FOREIGN KEY(writer) REFERENCES employee(emp_cd) 
) type=innodb;
GRANT ALL ON masters.telmemo2 TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS torihikisaki (
  toricode character varying(10) NOT NULL,
  input_emp_cd CHARACTER VARYING(50),
  syamei CHARACTER VARYING(50),
  shihon INTEGER,
  bank TEXT,
  gyomu TEXT,
  last_name_j CHARACTER VARYING(10),
  first_name_j CHARACTER VARYING(10),
  last_name_e CHARACTER VARYING(20),
  first_name_e CHARACTER VARYING(20),
  email CHARACTER VARYING(50),
  web CHARACTER VARYING(100),
  CONSTRAINT torihikisaki_pkey PRIMARY KEY(toricode)
) type=innodb;
GRANT ALL ON masters.torihikisaki TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS tantou (
  seq CHARACTER VARYING(10) NOT NULL,
  toricode CHARACTER VARYING(10),
  last_name_j CHARACTER VARYING(10),
  first_name_j CHARACTER VARYING(10),
  last_name_e CHARACTER VARYING(20),
  first_name_e CHARACTER VARYING(20),
  sex CHARACTER VARYING(1),
  busyo CHARACTER VARYING(100),
  yaku CHARACTER VARYING(100),
  phone CHARACTER VARYING(20),
  fax CHARACTER VARYING(20),
  handy CHARACTER VARYING(20),
  email CHARACTER VARYING(50),
  gyomu CHARACTER VARYING(255),
  memo CHARACTER VARYING(255),
  bashocode character varying(10),
  input_emp_cd character varying(50),
  CONSTRAINT tantou_pkey PRIMARY KEY(seq)
) type=innodb;
GRANT ALL ON masters.tantou TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS tori_place (
  toricode character varying(10) NOT NULL,
  bashocode character varying(10) NOT NULL,
  input_emp_cd CHARACTER VARYING(50),
  bashomei CHARACTER VARYING(50),
  postal CHARACTER VARYING(7),
  address TEXT,
  tel CHARACTER VARYING(20),
  fax CHARACTER VARYING(20),
  CONSTRAINT tori_place_pkey PRIMARY KEY(toricode,bashocode)
) TYPE=INNODB;
GRANT ALL ON masters.tori_place TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS record_access (
  up_time DATETIME NOT NULL,
  group_cd INTEGER NOT NULL,
  readable_status CHARACTER VARYING(1) DEFAULT 'F',
  CONSTRAINT record_access_pkey PRIMARY KEY(up_time,group_cd)
) TYPE=INNODB;
GRANT ALL ON masters.record_access TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS group_relation (
  group_cd INTEGER NOT NULL,
  emp_cd CHARACTER VARYING(50) NOT NULL,
  CONSTRAINT group_relation_pkey PRIMARY KEY(group_cd,emp_cd)
) TYPE=INNODB;
GRANT ALL ON masters.group_relation TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS group_master (
    group_cd INTEGER NOT NULL,
    group_name CHARACTER VARYING(50) NOT NULL,
    owner_emp_cd CHARACTER VARYING(50) NOT NULL
) TYPE=INNODB;
GRANT ALL ON masters.group_master TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS serialnumber (
  name CHARACTER VARYING(50) NOT NULL,
  code int4,
  CONSTRAINT serialnumber_pkey PRIMARY KEY(name)
) type=innodb;
GRANT ALL ON masters.serialnumber TO nobody;
FLUSH PRIVILEGES;


CREATE TABLE IF NOT EXISTS forums (
  id int unsigned DEFAULT 0 NOT NULL AUTO_INCREMENT,
  name char(50) DEFAULT '' NOT NULL,
  active smallint DEFAULT 0 NOT NULL,
  description char(255) DEFAULT '' NOT NULL,
  config_suffix char(50) DEFAULT '' NOT NULL,
  folder char(1) DEFAULT '0' NOT NULL,
  parent int unsigned DEFAULT 0 NOT NULL,
  display int unsigned DEFAULT 0 NOT NULL,
  table_name char(50) DEFAULT '' NOT NULL,
  moderation char(1) DEFAULT 'n' NOT NULL,
  email_list char(50) DEFAULT '' NOT NULL,
  email_return char(50) DEFAULT '' NOT NULL,
  email_tag char(50) DEFAULT '' NOT NULL,
  check_dup smallint unsigned DEFAULT 0 NOT NULL,
  multi_level smallint unsigned DEFAULT 0 NOT NULL,
  collapse smallint unsigned DEFAULT 0 NOT NULL,
  flat smallint unsigned DEFAULT 0 NOT NULL,
  lang char(50) DEFAULT '' NOT NULL,
  html char(40) DEFAULT 'N' NOT NULL,
  table_width char(4) DEFAULT '' NOT NULL,
  table_header_color char(7) DEFAULT '' NOT NULL,
  table_header_font_color char(7) DEFAULT '' NOT NULL,
  table_body_color_1 char(7) DEFAULT '' NOT NULL,
  table_body_color_2 char(7) DEFAULT '' NOT NULL,
  table_body_font_color_1 char(7) DEFAULT '' NOT NULL,
  table_body_font_color_2 char(7) DEFAULT '' NOT NULL,
  nav_color char(7) DEFAULT '' NOT NULL,
  nav_font_color char(7) DEFAULT '' NOT NULL,
  allow_uploads char(1) DEFAULT 'N' NOT NULL,
  upload_types char(100) DEFAULT '' NOT NULL,
  upload_size int unsigned DEFAULT '0' NOT NULL,
  max_uploads int unsigned DEFAULT '0' NOT NULL,
  security int unsigned DEFAULT '0' NOT NULL,
  showip smallint unsigned DEFAULT 1 NOT NULL,
  emailnotification smallint unsigned DEFAULT 1 NOT NULL,
  body_color char(7) DEFAULT '' NOT NULL,
  body_link_color char(7) DEFAULT '' NOT NULL,
  body_alink_color char(7) DEFAULT '' NOT NULL,
  body_vlink_color char(7) DEFAULT '' NOT NULL,
  CONSTRAINT forums_pkey PRIMARY KEY(id),
  KEY (name),
  KEY (active),
  KEY (parent),
  key (security)
) type=innodb;

GRANT ALL ON masters.forums TO nobody;
FLUSH PRIVILEGES;

CREATE TABLE IF NOT EXISTS mst_menu_category (
  menu_category_id integer NOT NULL,
  menu_category_name varchar(50),
  menu_category_image varchar(50),
  menu_category_order integer,
  CONSTRAINT mst_menu_category_pkey PRIMARY KEY(menu_category_id)
) type=innodb;

GRANT ALL ON masters.mst_menu_category TO nobody;
FLUSH PRIVILEGES;



CREATE TABLE  IF NOT EXISTS group_access (
	cat_cd	character varying(10) NOT NULL,
	subcat_cd	character varying(10) NOT NULL,
	group_cd	character varying(10) NOT NULL,
	writeable	character varying(1)  DEFAULT 't' NOT NULL
) type=innodb;

GRANT ALL ON masters.group_access TO nobody;
FLUSH PRIVILEGES;

ALTER TABLE group_master ADD CONSTRAINT group_master_group_cd PRIMARY KEY(group_cd);
ALTER TABLE group_master ADD COLUMN public_flg character varying(1) DEFAULT 't' NOT NULL;
ALTER TABLE group_master ALTER COLUMN public_flg SET DEFAULT 'f';

CREATE TABLE onetime_password (
  emp_cd CHARACTER VARYING(50) NOT NULL,
  pass CHARACTER VARYING(10) NOT NULL,
  login_limit DATETIME NOT NULL,
  delete_limit DATETIME NOT NULL
) type=innodb;
GRANT ALL ON masters.onetime_password TO nobody;
FLUSH PRIVILEGES;

#INSERT INTO APPCONF
INSERT INTO appconf VALUES('mygroup','롼','t','emp_group.php','maintenance_title.gif','f',2,'myGroup',8);
INSERT INTO appconf VALUES('home','HOME','t','index.php','index_title.gif','t',0,'HOME',1);
INSERT INTO appconf VALUES('conf','','t','confmenu.php','maintenance_title.gif','t',0,'',8);
INSERT INTO appconf VALUES('p_info','Ŀ;','t','phonebook.php','personal_readtitle.gif','f',12,'Colleagues Information',4);
INSERT INTO appconf VALUES('com_event','ҹԻͽ','t','monsche.php','com_event_title.gif','f',6,'Schedules of Business',1);
INSERT INTO appconf VALUES('telmemo','','t','telmemo.php','message_title.gif','f',3,'Message Notes',2);
INSERT INTO appconf VALUES('reserve','ͽ','t','reserve.php','institution_title.gif','f',7,'Bookings of Facilities',5);
INSERT INTO appconf VALUES('clnt','衦ôԾ','t','client.php','customer_title.gif','f',45,'Information of Clients',4);
INSERT INTO appconf VALUES('empedit','Ŀ;Խ','t','emp.php','maintenance_title.gif','f',13,'Self-information',8);
INSERT INTO appconf VALUES('passwd','ѥѹ','t','passwd.php','pass_title.gif','f',70,'Password Change',6);
INSERT INTO appconf VALUES('workflow','ե','t','workflow.php','workflow_title.gif','f',60,'Applications',3);
INSERT INTO appconf VALUES('flowpetit','','t','flowpetit.php','settlement_title.gif','f',65,'Decisions',3);
INSERT INTO appconf VALUES('bbs','Ǽ','t','bbs/index.php','bbs_title.gif','f',5,'BBS',4);
INSERT INTO appconf VALUES('rota','ɽ','t','rota.php','duty_title.gif','f',8,'Turns of Duty',1);
INSERT INTO appconf VALUES('scdl','塼Ģ','t','schedule2.php','schedule_title.gif','f',2,'Personal Schedule',1);
INSERT INTO appconf VALUES('notice','','t','notice1.php','circulation_title.gif','f',6,'Circular Board',1);
INSERT INTO appconf VALUES('document','ե붦ͭ','t','record.php','document_title.gif','f',79,'Library',4);
INSERT INTO appconf VALUES('white','ܡ','t','whiteboard1.php','destination_title.gif','f',1,'Whiteboard System',2);


#INSERT into CATEGORY
INSERT INTO category VALUES(1,'ĻϿ','t');


#INSERT INTO COMPANY
INSERT INTO company VALUES('WIZ','WIZ','1900-01-01',1,'http://localhost/','wiz@wiz','WIZϺ');

#INSERT into DIVISION
INSERT INTO division VALUES(1,'̳');

#INSERT INTO facility_category
INSERT INTO facility_category (fac_cat_cd, fac_cat_name, enable) VALUES('1', 'Default', 't');

#INSERT into FACILITIES
INSERT INTO facilities VALUES('1','ļ','t','1');

#INSERT INTO HOLIDAY
INSERT INTO holiday VALUES('2004-01-01','','f');
INSERT INTO holiday VALUES('2004-01-12','ͤ','f');
INSERT INTO holiday VALUES('2004-02-11','ǰ','f');
INSERT INTO holiday VALUES('2004-03-20','ʬ','f');
INSERT INTO holiday VALUES('2004-04-29','ߤɤ','f');
INSERT INTO holiday VALUES('2004-05-03','ˡǰ','f');
INSERT INTO holiday VALUES('2004-05-04','̱ν','f');
INSERT INTO holiday VALUES('2004-05-05','ɤ','f');
INSERT INTO holiday VALUES('2004-07-19','','f');
INSERT INTO holiday VALUES('2004-09-20','Ϸ','f');
INSERT INTO holiday VALUES('2004-09-23','ʬ','f');
INSERT INTO holiday VALUES('2004-10-11','ΰ','f');
INSERT INTO holiday VALUES('2004-11-03','ʸ','f');
INSERT INTO holiday VALUES('2004-11-23','ϫդ','f');
INSERT INTO holiday VALUES('2004-12-23','ŷ','f');

#INSERT into MST_TOUBAN
INSERT INTO mst_touban VALUES('1','','');

#INSERT into MST_TYPE
INSERT INTO mst_type VALUES(1,'Ұ');

#INSERT into EMPLOYEE
INSERT INTO employee VALUES('admin','uit0tkg6JSA0s','','','Initial','Administrator','礭','ꤷ','t','1',1,NULL,NULL,NULL,'1','','','','','','','','',1,'f');

#INSERT INTO ADMINISTRATORS
INSERT INTO administrators VALUES('admin');

#INSERT into SUBCATEGORY
INSERT INTO subcategory VALUES(1,'ͻ','t','1');

#INSERT INTO WHITEBOARD
INSERT INTO whiteboard VALUES('admin',0,'2001-06-27 09:01:29+09','Ĥξ','','admin');

#INSERT INTO CHIEF
INSERT INTO chief VALUES('admin','');

#INSERT INTO CHIEFEMP

#INSERT INTO serialnumber
INSERT INTO serialnumber VALUES('mst_type',2);
INSERT INTO serialnumber VALUES('division',2);
INSERT INTO serialnumber VALUES('mst_touban',2);
INSERT INTO serialnumber VALUES('facilities',2);
INSERT INTO serialnumber VALUES('subcategory',2);
INSERT INTO serialnumber VALUES('category',2);
INSERT INTO serialnumber VALUES('menu_category',9);

INSERT INTO mst_menu_category VALUES(1,'뤳ȥå','menu1.gif',1);
INSERT INTO mst_menu_category VALUES(2,'Фä','menu2.gif',2);
INSERT INTO mst_menu_category VALUES(3,'ȽǤĤ','menu3.gif',3);
INSERT INTO mst_menu_category VALUES(4,'ߤʤξ','menu4.gif',4);
INSERT INTO mst_menu_category VALUES(5,'񸻤Ȥ','menu5.gif',5);
INSERT INTO mst_menu_category VALUES(6,'ƥ','menu6.gif',6);
INSERT INTO mst_menu_category VALUES(7,'¾','menu7.gif',7);
INSERT INTO mst_menu_category VALUES(8,'','menu8.gif',8);

#UPDATE group_master
UPDATE group_master SET public_flg = 'f';
